==> AgeOn1.8.1_source.zip: AgeOn1.8.1_source/nispi/Controls/Menu/MainMenu/FileMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Drawing;
using System.Diagnostics;
using mshtml;

using nispi.controlclass;

namespace nispi
{
    class FileMenu
    {
        //ronin
        public ToolStripMenuItemParts mainMenuItemUseRonin;
        public ToolStripMenuItemParts mainMenuItemNotUseRonin;
        //be.2ch.net
        public ToolStripMenuItemParts mainMenuItemUseBe;
        public ToolStripMenuItemParts mainMenuItemNotUseBe;
        //be.2ch.sc
        public ToolStripMenuItemParts mainMenuItemUseSCBe;
        public ToolStripMenuItemParts mainMenuItemNotUseSCBe;


        public ToolStripMenuItemParts mainMenuItemOnLine;
        public ToolStripMenuItemParts mainMenuItemOffLine;
        public ToolStripMenuItemParts mainMenuItemTaskTray;
        public ToolStripMenuItemParts mainMenuItemExit;

        public ToolStripMenuItemParts mainMenuItemReStart;

        public NotifyIcon notifyIcon;

        public static MainForm form = null;

        public FileMenu(ToolStripMenuItemParts menuItem)
        {
            //ronin
            mainMenuItemUseRonin = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemNotUseRonin = ToolStripMenuItemPartsManager.Pop();
            //be.2ch.net
            mainMenuItemUseBe = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemNotUseBe = ToolStripMenuItemPartsManager.Pop();
            //be.2ch.sc
            mainMenuItemUseSCBe = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemNotUseSCBe = ToolStripMenuItemPartsManager.Pop();
            //IC^ItC
            mainMenuItemOnLine = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemOffLine = ToolStripMenuItemPartsManager.Pop();

            mainMenuItemTaskTray = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemExit = ToolStripMenuItemPartsManager.Pop();

            mainMenuItemReStart = ToolStripMenuItemPartsManager.Pop();

            mainMenuItemOnLine.Enabled = false;
            mainMenuItemOffLine.Enabled = true;

            //^XNg[
            this.notifyIcon = new NotifyIcon();
            this.notifyIcon.Icon = Resources.icon;
            this.notifyIcon.Visible = true;
            this.notifyIcon.Text = "AgeOn";
            this.notifyIcon.Click += new EventHandler(NotifyIcon_Click);

            //ronin
            mainMenuItemUseRonin.Text = "Qlgp";
            mainMenuItemUseRonin.Click += new EventHandler(mainMenuItemUseRonin_Click);
            mainMenuItemUseRonin.Image = Resources.ronin_login;

            mainMenuItemNotUseRonin.Text = "QlgpȂ";
            mainMenuItemNotUseRonin.Click += new EventHandler(mainMenuItemNotUseRonin_Click);
            mainMenuItemNotUseRonin.Image = Resources.ronin_logout;

            //be.2ch.net
            mainMenuItemUseBe.Text = "Begp";
            mainMenuItemUseBe.Click += new EventHandler(mainMenuItemUseBe_Click);
            mainMenuItemUseBe.Image = Resources.ronin_login;

            mainMenuItemNotUseBe.Text = "BegpȂ";
            mainMenuItemNotUseBe.Click += new EventHandler(mainMenuItemNotUseBe_Click);
            mainMenuItemNotUseBe.Image = Resources.ronin_logout;

            //be.2ch.sc
            mainMenuItemUseSCBe.Text = "Be(SC)gp";
            mainMenuItemUseSCBe.Click += new EventHandler(mainMenuItemUseSCBe_Click);
            mainMenuItemUseSCBe.Image = Resources.ronin_login;

            mainMenuItemNotUseSCBe.Text = "Be(SC)gpȂ";
            mainMenuItemNotUseSCBe.Click += new EventHandler(mainMenuItemNotUseSCBe_Click);
            mainMenuItemNotUseSCBe.Image = Resources.ronin_logout;

            //on/off
            mainMenuItemOnLine.Text = "IC";
            mainMenuItemOnLine.Click += new EventHandler(menuItemOnLine_Click);
            mainMenuItemOnLine.Image = Resources.online;

            mainMenuItemOffLine.Text = "ItC";
            mainMenuItemOffLine.Click += new EventHandler(menuItemOffLine_Click);
            mainMenuItemOffLine.Image = Resources.offline;

            mainMenuItemTaskTray.Text = "^XNgC";
            mainMenuItemTaskTray.Click += new EventHandler(menuItemTaskTray_Click);

            mainMenuItemExit.Text = "I";
            mainMenuItemExit.Image = Resources.CaptionClose;
            mainMenuItemExit.Click += new EventHandler(menuItemExit_Click);

            mainMenuItemReStart.Text = "ċN";
            mainMenuItemReStart.Click += new EventHandler(menuItemReStart_Click);

            menuItem.DropDownItemsAdd(mainMenuItemUseRonin);
            menuItem.DropDownItemsAdd(mainMenuItemNotUseRonin);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemUseBe);
            menuItem.DropDownItemsAdd(mainMenuItemNotUseBe);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemUseSCBe);
            menuItem.DropDownItemsAdd(mainMenuItemNotUseSCBe);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemOnLine);
            menuItem.DropDownItemsAdd(mainMenuItemOffLine);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemTaskTray);
            menuItem.DropDownItemsAdd(mainMenuItemReStart);
            menuItem.DropDownItemsAdd(mainMenuItemExit);
        }

        //ronin
        private void mainMenuItemUseRonin_Click(object sender, EventArgs e)
        {
            Ronin ronin = new Ronin();
            if (ronin.LogIn() == true)
            {
                //OCȂ烁j[
                mainMenuItemUseRonin.Enabled = false;
                mainMenuItemNotUseRonin.Enabled = true;
                Const.form.roninToolStripStatusLabel.Text = "RoninFOC@@@";
            }
            else
                Const.form.roninToolStripStatusLabel.Text = "RoninFOIt@@@";
        }
        private void mainMenuItemNotUseRonin_Click(object sender, EventArgs e)
        {
            Ronin ronin = new Ronin();
            ronin.LogOut();
            //j[
            mainMenuItemUseRonin.Enabled = true;
            mainMenuItemNotUseRonin.Enabled = false;
            Const.form.roninToolStripStatusLabel.Text = "RoninFOIt@@@";
        }
        //be.2ch.net
        private void mainMenuItemUseBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            if (be.GetBeCookie() == true)
            {
                //OCȂ烁j[
                mainMenuItemUseBe.Enabled = false;
                mainMenuItemNotUseBe.Enabled = true;
                Const.form.be2chToolStripStatusLabel.Text = "2chBeFOC@@@";
            }
            else
                Const.form.be2chToolStripStatusLabel.Text = "2chBeFOIt@@@";
        }
        private void mainMenuItemNotUseBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            be.LogOutBe();
            //j[
            mainMenuItemUseBe.Enabled = true;
            mainMenuItemNotUseBe.Enabled = false;
            Const.form.be2chToolStripStatusLabel.Text = "2chBeFOIt@@@";
        }
        //be.2ch.sc
        private void mainMenuItemUseSCBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            if (be.GetSCBeCookie() == true)
            {
                //OCȂ烁j[
                mainMenuItemUseSCBe.Enabled = false;
                mainMenuItemNotUseSCBe.Enabled = true;
                Const.form.beSCToolStripStatusLabel.Text = "2chBe(SC)FOC@@@";
            }
            else
                Const.form.beSCToolStripStatusLabel.Text = "2chBe(SC)FOIt@@@";
        }
        private void mainMenuItemNotUseSCBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            be.LogOutSCBe();
            //j[
            mainMenuItemUseSCBe.Enabled = true;
            mainMenuItemNotUseSCBe.Enabled = false;
            Const.form.beSCToolStripStatusLabel.Text = "2chBe(SC)FOIt@@@";
        }

        //on/off
        private void menuItemOnLine_Click(object sender, EventArgs e)
        {
            Const.OnLine = true;
            mainMenuItemOffLine.Enabled = true;
            mainMenuItemOnLine.Enabled = false;
            Const.form.onLineToolStripStatusLabel.Text = "ԁFIC@@@";
        }
        private void menuItemOffLine_Click(object sender, EventArgs e)
        {
            Const.OnLine = false;
            mainMenuItemOffLine.Enabled = false;
            mainMenuItemOnLine.Enabled = true;
            Const.form.onLineToolStripStatusLabel.Text = "ԁFItC@@@";
        }
        //^XNg[
        private void menuItemTaskTray_Click(object sender, EventArgs e)
        {
            Const.form.mainForm.Hide();
            Const.form.mapMainForm.mapMainForm.Hide();
        }

        private void NotifyIcon_Click(object sender, EventArgs e)
        {
            Const.form.mainForm.Show();
            Const.form.mapMainForm.mapMainForm.Show();
        }

        private void menuItemReStart_Click(object sender, EventArgs e)
        {
            System.Diagnostics.Process.Start("ExitAndRun.exe");
            this.notifyIcon.Dispose();
        }

        private void menuItemExit_Click(object sender, EventArgs e)
        {
            this.notifyIcon.Dispose();
            Const.form.mapMainForm.mapMainForm.Close();
            Const.form.mainForm.Close();
        }
    }
}

==> AgeOn2.2_source.zip: AgeOn2.2_source/nispi/Controls/Menu/MainMenu/FileMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Drawing;
using System.Diagnostics;
using mshtml;

using nispi.controlclass;

namespace nispi
{
    class FileMenu
    {
        //ronin
        public ToolStripMenuItemParts mainMenuItemUseRonin;
        public ToolStripMenuItemParts mainMenuItemNotUseRonin;
        //be.2ch.net
        public ToolStripMenuItemParts mainMenuItemUseBe;
        public ToolStripMenuItemParts mainMenuItemNotUseBe;
        //be.2ch.sc
        public ToolStripMenuItemParts mainMenuItemUseSCBe;
        public ToolStripMenuItemParts mainMenuItemNotUseSCBe;


        public ToolStripMenuItemParts mainMenuItemOnLine;
        public ToolStripMenuItemParts mainMenuItemOffLine;
        public ToolStripMenuItemParts mainMenuItemTaskTray;
        public ToolStripMenuItemParts mainMenuItemExit;

        public ToolStripMenuItemParts mainMenuItemReStart;

        public NotifyIcon notifyIcon;

        public static MainForm form = null;

        public FileMenu(ToolStripMenuItemParts menuItem)
        {
            //ronin
            mainMenuItemUseRonin = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemNotUseRonin = ToolStripMenuItemPartsManager.Pop();
            //be.2ch.net
            mainMenuItemUseBe = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemNotUseBe = ToolStripMenuItemPartsManager.Pop();
            //be.2ch.sc
            mainMenuItemUseSCBe = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemNotUseSCBe = ToolStripMenuItemPartsManager.Pop();
            //IC^ItC
            mainMenuItemOnLine = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemOffLine = ToolStripMenuItemPartsManager.Pop();

            mainMenuItemTaskTray = ToolStripMenuItemPartsManager.Pop();
            mainMenuItemExit = ToolStripMenuItemPartsManager.Pop();

            mainMenuItemReStart = ToolStripMenuItemPartsManager.Pop();

            mainMenuItemOnLine.Enabled = false;
            mainMenuItemOffLine.Enabled = true;

            //^XNg[
            this.notifyIcon = new NotifyIcon();
            this.notifyIcon.Icon = Resources.icon;
            this.notifyIcon.Visible = true;
            this.notifyIcon.Text = "AgeOn";
            this.notifyIcon.Click += new EventHandler(NotifyIcon_Click);

            //ronin
            mainMenuItemUseRonin.Text = "Qlgp(&R)";
            mainMenuItemUseRonin.Click += new EventHandler(mainMenuItemUseRonin_Click);
            mainMenuItemUseRonin.Image = Resources.ronin_login;

            mainMenuItemNotUseRonin.Text = "QlgpȂ(&E)";
            mainMenuItemNotUseRonin.Click += new EventHandler(mainMenuItemNotUseRonin_Click);
            mainMenuItemNotUseRonin.Image = Resources.ronin_logout;

            //be.2ch.net
            mainMenuItemUseBe.Text = "Begp(&B)";
            mainMenuItemUseBe.Click += new EventHandler(mainMenuItemUseBe_Click);
            mainMenuItemUseBe.Image = Resources.ronin_login;

            mainMenuItemNotUseBe.Text = "BegpȂ(&V)";
            mainMenuItemNotUseBe.Click += new EventHandler(mainMenuItemNotUseBe_Click);
            mainMenuItemNotUseBe.Image = Resources.ronin_logout;

            //be.2ch.sc
            mainMenuItemUseSCBe.Text = "Be(SC)gp(&S)";
            mainMenuItemUseSCBe.Click += new EventHandler(mainMenuItemUseSCBe_Click);
            mainMenuItemUseSCBe.Image = Resources.ronin_login;

            mainMenuItemNotUseSCBe.Text = "Be(SC)gpȂ(&A)";
            mainMenuItemNotUseSCBe.Click += new EventHandler(mainMenuItemNotUseSCBe_Click);
            mainMenuItemNotUseSCBe.Image = Resources.ronin_logout;

            //on/off
            mainMenuItemOnLine.Text = "IC(&W)";
            mainMenuItemOnLine.Click += new EventHandler(menuItemOnLine_Click);
            mainMenuItemOnLine.Image = Resources.online;

            mainMenuItemOffLine.Text = "ItC(&F)";
            mainMenuItemOffLine.Click += new EventHandler(menuItemOffLine_Click);
            mainMenuItemOffLine.Image = Resources.offline;

            mainMenuItemTaskTray.Text = "^XNgC(&T)";
            mainMenuItemTaskTray.Click += new EventHandler(menuItemTaskTray_Click);

            mainMenuItemExit.Text = "I(&Q)";
            mainMenuItemExit.Image = Resources.CaptionClose;
            mainMenuItemExit.Click += new EventHandler(menuItemExit_Click);

            mainMenuItemReStart.Text = "ċN(&X)";
            mainMenuItemReStart.Click += new EventHandler(menuItemReStart_Click);

            menuItem.DropDownItemsAdd(mainMenuItemUseRonin);
            menuItem.DropDownItemsAdd(mainMenuItemNotUseRonin);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemUseBe);
            menuItem.DropDownItemsAdd(mainMenuItemNotUseBe);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemUseSCBe);
            menuItem.DropDownItemsAdd(mainMenuItemNotUseSCBe);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemOnLine);
            menuItem.DropDownItemsAdd(mainMenuItemOffLine);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(mainMenuItemTaskTray);
            menuItem.DropDownItemsAdd(mainMenuItemReStart);
            menuItem.DropDownItemsAdd(mainMenuItemExit);
        }

        //ronin
        private void mainMenuItemUseRonin_Click(object sender, EventArgs e)
        {
            Ronin ronin = new Ronin();
            if (ronin.LogIn() == true)
            {
                //OCȂ烁j[
                mainMenuItemUseRonin.Enabled = false;
                mainMenuItemNotUseRonin.Enabled = true;
                Const.form.roninToolStripStatusLabel.Text = "RoninFOC@@@";
            }
            else
                Const.form.roninToolStripStatusLabel.Text = "RoninFOIt@@@";
        }
        private void mainMenuItemNotUseRonin_Click(object sender, EventArgs e)
        {
            Ronin ronin = new Ronin();
            ronin.LogOut();
            //j[
            mainMenuItemUseRonin.Enabled = true;
            mainMenuItemNotUseRonin.Enabled = false;
            Const.form.roninToolStripStatusLabel.Text = "RoninFOIt@@@";
        }
        //be.2ch.net
        private void mainMenuItemUseBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            if (be.GetBeCookie() == true)
            {
                //OCȂ烁j[
                mainMenuItemUseBe.Enabled = false;
                mainMenuItemNotUseBe.Enabled = true;
                Const.form.be2chToolStripStatusLabel.Text = "2chBeFOC@@@";
            }
            else
                Const.form.be2chToolStripStatusLabel.Text = "2chBeFOIt@@@";
        }
        private void mainMenuItemNotUseBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            be.LogOutBe();
            //j[
            mainMenuItemUseBe.Enabled = true;
            mainMenuItemNotUseBe.Enabled = false;
            Const.form.be2chToolStripStatusLabel.Text = "2chBeFOIt@@@";
        }
        //be.2ch.sc
        private void mainMenuItemUseSCBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            if (be.GetSCBeCookie() == true)
            {
                //OCȂ烁j[
                mainMenuItemUseSCBe.Enabled = false;
                mainMenuItemNotUseSCBe.Enabled = true;
                Const.form.beSCToolStripStatusLabel.Text = "2chBe(SC)FOC@@@";
            }
            else
                Const.form.beSCToolStripStatusLabel.Text = "2chBe(SC)FOIt@@@";
        }
        private void mainMenuItemNotUseSCBe_Click(object sender, EventArgs e)
        {
            Be be = new Be();
            be.LogOutSCBe();
            //j[
            mainMenuItemUseSCBe.Enabled = true;
            mainMenuItemNotUseSCBe.Enabled = false;
            Const.form.beSCToolStripStatusLabel.Text = "2chBe(SC)FOIt@@@";
        }

        //on/off
        private void menuItemOnLine_Click(object sender, EventArgs e)
        {
            Const.OnLine = true;
            mainMenuItemOffLine.Enabled = true;
            mainMenuItemOnLine.Enabled = false;
            Const.form.onLineToolStripStatusLabel.Text = "ԁFIC@@@";
        }
        private void menuItemOffLine_Click(object sender, EventArgs e)
        {
            Const.OnLine = false;
            mainMenuItemOffLine.Enabled = false;
            mainMenuItemOnLine.Enabled = true;
            Const.form.onLineToolStripStatusLabel.Text = "ԁFItC@@@";
        }
        //^XNg[
        private void menuItemTaskTray_Click(object sender, EventArgs e)
        {
            Const.form.mainForm.Hide();
            Const.form.mapMainForm.mapMainForm.Hide();
        }

        private void NotifyIcon_Click(object sender, EventArgs e)
        {
            Const.form.mainForm.Show();
            Const.form.mapMainForm.mapMainForm.Show();
        }

        private void menuItemReStart_Click(object sender, EventArgs e)
        {
            System.Diagnostics.Process.Start("ExitAndRun.exe");
            this.notifyIcon.Dispose();
        }

        private void menuItemExit_Click(object sender, EventArgs e)
        {
            this.notifyIcon.Dispose();
            Const.form.mapMainForm.mapMainForm.Close();
            Const.form.mainForm.Close();
        }
    }
}
